# Code de conduite du Contributeur Covenant

## Notre Engagement

En tant que membres, contributeurs et leaders, nous nous engageons à faire de la participation à notre communauté une expérience sans harcèlement pour tous, quel que soit l'âge, la taille du corps, le handicap visible ou invisible, l'origine ethnique, les caractéristiques sexuelles, l'identité et l'expression de genre, le niveau d'expérience, l'éducation, le statut socio-économique, la nationalité, l'apparence personnelle, la race, la religion ou l'identité et l'orientation sexuelles.

Nous nous engageons à agir et à interagir de manière à contribuer à une communauté ouverte, accueillante, diverse, inclusive et saine.

## Nos normes

Exemples de comportements qui contribuent à un environnement positif pour notre communauté incluent :

* Faire preuve d'empathie et de gentillesse envers les autres  
* Respecter les opinions, points de vue et expériences différents  
* Donner et accepter avec grâce les retours constructifs  
* Assumer la responsabilité et s'excuser auprès des personnes affectées par nos erreurs, et apprendre de l'expérience  
* Se concentrer sur ce qui est le mieux, non seulement pour nous en tant qu'individus, mais aussi pour l'ensemble de la communauté

Exemples de comportements inacceptables incluent :

* L'utilisation d'un langage ou d'imagerie sexualisés, et toute attention ou avance de nature sexuelle  
* Le trollage, les commentaires insultants ou désobligeants, et les attaques personnelles ou politiques  
* Le harcèlement, public ou privé  
* La publication d'informations privées d'autrui, telles qu'une adresse physique ou électronique, sans leur permission explicite  
* Tout autre comportement qui pourrait raisonnablement être considéré comme inapproprié dans un cadre professionnel

## Responsabilités d'application

Les leaders de la communauté sont responsables de clarifier et de faire respecter nos normes de comportement acceptable et prendront des mesures correctives appropriées et équitables en réponse à tout comportement qu'ils jugent inapproprié, menaçant, offensant ou nuisible.

Les leaders de la communauté ont le droit et la responsabilité de supprimer, modifier ou rejeter les commentaires, commits, code, modifications de wiki, problèmes et autres contributions qui ne sont pas conformes à ce Code de Conduite, et communiqueront les raisons des décisions de modération lorsque cela est approprié.

## Portée

Ce Code de conduite s'applique dans tous les espaces communautaires, et s'applique également lorsqu'un individu représente officiellement la communauté dans des espaces publics. Des exemples de représentation de notre communauté incluent l'utilisation d'une adresse e-mail officielle, la publication via un compte officiel sur les réseaux sociaux, ou le fait d'agir en tant que représentant désigné lors d'un événement en ligne ou hors ligne.

## Application

Les cas de comportement abusif, harcelant ou autrement inacceptable peuvent être signalés aux responsables de la communauté chargés de l'application des règles à l'adresse `aw@funstory.ai`.  
Toutes les plaintes seront examinées et traitées rapidement et équitablement.  

Tous les responsables de la communauté sont tenus de respecter la confidentialité et la sécurité du signalant de tout incident.

## Directives d'application

Les leaders de la communauté suivront ces directives d'impact communautaire pour déterminer les conséquences de toute action qu'ils jugent en violation de ce code de conduite :

### 1. Correction

**Impact sur la communauté** : Utilisation d'un langage inapproprié ou tout autre comportement jugé non professionnel ou indésirable dans la communauté.

**Conséquence** : Un avertissement privé et écrit des responsables de la communauté, clarifiant la nature de la violation et expliquant pourquoi le comportement était inapproprié. Des excuses publiques peuvent être demandées.

### 2. Avertissement

**Impact sur la communauté** : Une violation à travers un incident unique ou une série d'actions.

**Conséquence** : Un avertissement avec des conséquences pour un comportement persistant. Aucune interaction avec les personnes concernées, y compris les interactions non sollicitées avec celles faisant respecter le Code de conduite, pour une période de temps spécifiée. Cela inclut d'éviter les interactions dans les espaces communautaires ainsi que les canaux externes comme les médias sociaux. Enfreindre ces conditions peut entraîner une interdiction temporaire ou permanente.

### 3. Bannissement temporaire

**Impact sur la communauté** : Une violation grave des normes de la communauté, incluant un comportement inapproprié persistant.

**Conséquence** : Un bannissement temporaire de toute forme d'interaction ou de communication publique avec la communauté pour une période déterminée. Aucune interaction publique ou privée avec les personnes concernées, y compris des interactions non sollicitées avec celles chargées de faire respecter le Code de conduite, n'est autorisée pendant cette période. Le non-respect de ces conditions peut entraîner un bannissement permanent.

### 4. Bannissement permanent

**Impact sur la communauté** : Démontrer un schéma de violation des normes communautaires, incluant un comportement inapproprié persistant, le harcèlement d'un individu, ou de l'agressivité ou des propos dénigrants envers des groupes d'individus.

**Conséquence** : Un bannissement permanent de toute forme d'interaction publique au sein de la communauté.

## Attribution

Ce Code de Conduite est adapté du [Contributor Covenant][homepage], version 2.0, disponible à l'adresse https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Les directives d'impact communautaire ont été inspirées par [l'échelle d'application du code de conduite de Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Pour les réponses aux questions courantes concernant ce code de conduite, consultez la FAQ à l'adresse https://www.contributor-covenant.org/faq. Les traductions sont disponibles sur https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>